==> haskell-generic-data-1.1.0.2-26-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-generic-data.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 generic-data
version:              1.1.0.2
visibility:           public
id:                   generic-data-1.1.0.2-FLqqVvPmQJt2g0hiu1054w
key:                  generic-data-1.1.0.2-FLqqVvPmQJt2g0hiu1054w
license:              MIT
copyright:            2018-2020 Li-yao Xia
maintainer:           lysxia@gmail.com
author:               Li-yao Xia
homepage:             https://github.com/Lysxia/generic-data#readme
synopsis:             Deriving instances with GHC.Generics and related utilities
description:
    Generic implementations of standard type classes.
    Operations on generic representations to help using "GHC.Generics".
    See README.

category:             Generics
abi:                  c8ff2b20ed726e7792ea0a4acf85e58b
exposed:              True
exposed-modules:
    Generic.Data Generic.Data.Internal.Compat
    Generic.Data.Internal.Data Generic.Data.Internal.Enum
    Generic.Data.Internal.Error Generic.Data.Internal.Functions
    Generic.Data.Internal.Generically Generic.Data.Internal.Meta
    Generic.Data.Internal.Microsurgery Generic.Data.Internal.Newtype
    Generic.Data.Internal.Prelude Generic.Data.Internal.Read
    Generic.Data.Internal.Resolvers Generic.Data.Internal.Show
    Generic.Data.Internal.Traversable Generic.Data.Internal.Utils
    Generic.Data.Microsurgery Generic.Data.Orphans Generic.Data.Types

import-dirs:          /usr/lib/ghc-9.4.8/site-local/generic-data-1.1.0.2
library-dirs:         /usr/lib/ghc-9.4.8/site-local/generic-data-1.1.0.2
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/generic-data-1.1.0.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-generic-data
hs-libraries:         HSgeneric-data-1.1.0.2-FLqqVvPmQJt2g0hiu1054w
depends:
    ap-normalize-0.1.0.1-2OIZezFTFdID4zyW3I24kv base-4.17.2.1
    base-orphans-0.9.3-7fWGJ65YI9v69IsoUT6loi
    contravariant-1.5.5-p3peIMeiUA4Z37z2EtgYi ghc-boot-th-9.4.8
    show-combinators-0.2.0.0-6ZAszFLrSaHXY65bXLH1d

haddock-interfaces:
    /usr/share/doc/haskell-generic-data/html/generic-data.haddock

haddock-html:         /usr/share/doc/haskell-generic-data/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-generic-data-1.1.0.2-27-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-generic-data.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 generic-data
version:              1.1.0.2
visibility:           public
id:                   generic-data-1.1.0.2-7p0bsJSBchGIoxvE2Nj1BT
key:                  generic-data-1.1.0.2-7p0bsJSBchGIoxvE2Nj1BT
license:              MIT
copyright:            2018-2020 Li-yao Xia
maintainer:           lysxia@gmail.com
author:               Li-yao Xia
homepage:             https://github.com/Lysxia/generic-data#readme
synopsis:             Deriving instances with GHC.Generics and related utilities
description:
    Generic implementations of standard type classes.
    Operations on generic representations to help using "GHC.Generics".
    See README.

category:             Generics
abi:                  8847566551548311d1f8b183dbafc151
exposed:              True
exposed-modules:
    Generic.Data Generic.Data.Internal.Compat
    Generic.Data.Internal.Data Generic.Data.Internal.Enum
    Generic.Data.Internal.Error Generic.Data.Internal.Functions
    Generic.Data.Internal.Generically Generic.Data.Internal.Meta
    Generic.Data.Internal.Microsurgery Generic.Data.Internal.Newtype
    Generic.Data.Internal.Prelude Generic.Data.Internal.Read
    Generic.Data.Internal.Resolvers Generic.Data.Internal.Show
    Generic.Data.Internal.Traversable Generic.Data.Internal.Utils
    Generic.Data.Microsurgery Generic.Data.Orphans Generic.Data.Types

import-dirs:          /usr/lib/ghc-9.4.8/site-local/generic-data-1.1.0.2
library-dirs:         /usr/lib/ghc-9.4.8/site-local/generic-data-1.1.0.2
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/generic-data-1.1.0.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-generic-data
hs-libraries:         HSgeneric-data-1.1.0.2-7p0bsJSBchGIoxvE2Nj1BT
depends:
    ap-normalize-0.1.0.1-2OIZezFTFdID4zyW3I24kv base-4.17.2.1
    base-orphans-0.9.3-K3quPKCpRSqBwclXxVlZBv
    contravariant-1.5.5-p3peIMeiUA4Z37z2EtgYi ghc-boot-th-9.4.8
    show-combinators-0.2.0.0-6ZAszFLrSaHXY65bXLH1d

haddock-interfaces:
    /usr/share/doc/haskell-generic-data/html/generic-data.haddock

haddock-html:         /usr/share/doc/haskell-generic-data/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
